@@ -142,6 +142,7 @@ sub prepare_path {
     $base->port( $c->apache_request->get_server_port );
     $base->path( $c->apache_request->location );
     $c->req->base( $base->as_string );
+    $c->req->server_base( $base->scheme . '://' . $base->authority . '/' );
 }
 
 =head3 prepare_request
@@ -162,11 +163,10 @@ sub prepare_uploads {
     my $c = shift;
     for my $upload ( $c->apache_request->upload ) {
         $upload = $c->apache_request->upload($upload) if MP2;
-        $c->req->uploads->{ $upload->name } = {
-            fh       => $upload->fh,
-            filename => $upload->filename,
-            size     => $upload->size,
-            type     => $upload->type
+        $c->req->uploads->{ $upload->filename } = {
+            fh   => $upload->fh,
+            size => $upload->size,
+            type => $upload->type
         };
     }
 }
