@@ -125,6 +125,7 @@ sub prepare_path {
     $base = URI->new($base);
     $base->path('/') if ( $ENV{CATALYST_TEST} || !$base->path );
     $c->req->base( $base->as_string );
+    $c->req->server_base( $base->scheme . '://' . $base->authority . '/' );
 }
 
 =head3 prepare_request
@@ -166,4 +167,3 @@ the same terms as Perl itself.
 =cut
 
 1;
-## Please see file perltidy.ERR
